@@ -1,6 +1,6 @@
 package Tapper::Reports::Web::Controller::Tapper::Metareports;
 our $AUTHORITY = 'cpan:TAPPER';
-$Tapper::Reports::Web::Controller::Tapper::Metareports::VERSION = '5.0.5';
+$Tapper::Reports::Web::Controller::Tapper::Metareports::VERSION = '5.0.6';
 # ABSTRACT: Tapper - Catalyst Controller Metareports
 
 use strict;
@@ -191,7 +191,7 @@ sub chart_overview : Local {
     };
 
     my $i_chart_tag = $or_c->req->params->{chart_tag};
-    if ( $i_chart_tag && $i_chart_tag ne 'all' ) {
+    if ( defined($i_chart_tag) && $i_chart_tag ne '0' ) {
         $hr_where->{'chart_tag_relations.chart_tag_id'} = $i_chart_tag;
         push @{$hr_options->{join}}, 'chart_tag_relations';
     }
@@ -1102,10 +1102,10 @@ sub save_chart : Local {
     };
 
     $or_c->redirect(
-          '/tapper/metareports/detail?chart_id='
-        . $or_c->stash->{chart}{chart_id}
-        . '&amp;chart_tag='
+          '/tapper/metareports/detail?chart_tag='
         . $or_c->req->params->{chart_tag}
+        . '&amp;chart_id='
+        . $or_c->stash->{chart}{chart_id}
     );
     $or_c->detach();
 
